;; Generated package description from popup.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "popup" "0.5.9.0.20260619.57" "Visual Popup User Interface" '((emacs "24.3")) :commit "3afe431e9aa2e271aaf0412cbb50c733387e8ea4" :authors '(("Tomohiro Matsuyama" . "m2ym.pub@gmail.com")) :maintainer '("Jen-Chieh" . "jcs090218@gmail.com") :keywords '("lisp") :url "https://github.com/auto-complete/popup-el")
